/*
 *    Copyright 2009-2010 The Rocoto Team
 *
 *    Licensed under the Apache License, Version 2.0 (the "License");
 *    you may not use this file except in compliance with the License.
 *    You may obtain a copy of the License at
 *
 *       http://www.apache.org/licenses/LICENSE-2.0
 *
 *    Unless required by applicable law or agreed to in writing, software
 *    distributed under the License is distributed on an "AS IS" BASIS,
 *    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *    See the License for the specific language governing permissions and
 *    limitations under the License.
 */
package com.googlecode.rocoto.simpleconfig;

import java.util.Iterator;
import java.util.Map;
import java.util.Map.Entry;

/**
 * 
 * @author Simone Tripodi
 * @since 3.2
 * @version $Id: PropertiesIterator.java 491 2010-10-01 13:16:22Z simone.tripodi $
 */
final class PropertiesIterator implements Iterator<Entry<String, String>> {

    private final String keyPrefix;

    private final Iterator<?> propertiesIterator;

    public PropertiesIterator(String keyPrefix, Map<?, ?> properties) {
        this.keyPrefix = keyPrefix;
        this.propertiesIterator = properties.entrySet().iterator();
    }

    /**
     * {@inheritDoc}
     */
    public boolean hasNext() {
        return this.propertiesIterator.hasNext();
    }

    /**
     * {@inheritDoc}
     */
    public Entry<String, String> next() {
        Entry<?, ?> next = (Entry<?, ?>) this.propertiesIterator.next();
        String key = String.valueOf(next.getKey());
        if (this.keyPrefix != null && this.keyPrefix.length() > 0) {
            key = this.keyPrefix + key;
        }
        return new KeyValue(key, String.valueOf(next.getValue()));
    }

    /**
     * {@inheritDoc}
     */
    public void remove() {
        // not needed in this version
    }

}
